Package: BLMA
Date: 2020-06-22
Type: Package
Title: BLMA: A package for bi-level meta-analysis
Version: 1.37.0
Author: Tin Nguyen <tinn@auburn.edu>, Hung Nguyen <pzb00047@auburn.edu>, and Sorin Draghici <sorin@wayne.edu>
Maintainer: Van-Dung Pham <dvp0001@auburn.edu>
Description: Suit of tools for bi-level meta-analysis. The package can
        be used in a wide range of applications, including general
        hypothesis testings, differential expression analysis,
        functional analysis, and pathway analysis.
biocViews: GeneSetEnrichment, Pathways, DifferentialExpression,
        Microarray
License: GPL (>=2)
Depends: ROntoTools, GSA, PADOG, limma, graph, stats, utils, parallel,
        Biobase, metafor, methods
Suggests: RUnit, BiocGenerics
RoxygenNote: 7.3.1
NeedsCompilation: no
git_url: https://git.bioconductor.org/packages/BLMA
git_branch: devel
git_last_commit: 72ed5fb
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
Packaged: 2026-04-28 21:37:21 UTC; biocbuild
